@@ -3,12 +3,13 @@ options(width = 90)
 
 ## ---------------------------------------------------------------------------------------
 library("grex")
-data("gtexv6")
-id = gtexv6[101:200]
+data("gtexv6p")
+id = gtexv6p[101:200]
 df = grex(id)
 tail(df)
 
 ## ---------------------------------------------------------------------------------------
-filtered_genes = df[!is.na(df$entrez_id), c('ensembl_id', 'entrez_id')]
+filtered_genes = df[!is.na(df$"entrez_id"),
+                    c("ensembl_id", "entrez_id", "hgnc_symbol", "gene_biotype")]
 head(filtered_genes)
 
